/*  JarBuilder.java
 *
 *  Copyright (C) 2002-2003 Dominik Werthmueller
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package ch.fulgur.jarbuilder;
 
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;



/**
 * JarBuilder.java
 *
 * @version 0.8.0
 * @author Dominik Werthmueller
 *
 */
public class JarBuilder extends JFrame implements JBMenuInterface, JBButtonInterface {

	//private static JarBuilder app;
	private JBCore jbcore;
	private VarUtils varutils;

	private JPanel panelMain;
	private Panel1 panel1;
	private Panel2 panel2;
	private Panel3 panel3;
	private Panel4 panel4;

	
	// ---------- Start implementation of the inherited abstract methods from JBMenuInterface ----------
	
	public void requestMenuCreateJar() {
		jbcore.prepareJar();
	}
	
	public void requestMenuQuit() {
		dispose();
		System.exit(0);
	}
	
	public void requestMenuAddFiles() {
		jbcore.loadFiles();
	}
	
	public void requestMenuRemoveFiles() {
		jbcore.removeEntry();
	}

	public void requestMenuClearList() {
		jbcore.clearFileList();
	}
	
	public void requestMenuHelpContents() {
		JOptionPane.showMessageDialog(this, "not implemented yet", "JarBuilder Help", JOptionPane.ERROR_MESSAGE);
	}
	
	public void requestMenuAbout() {
		JOptionPane.showMessageDialog(
			this,
			"JarBuilder\n"
				+ "Version 0.8.0\n"
				+ "Copyright (c) 2002-2003 by Dominik Werthmueller <werti@gmx.net>\n"
				+ "Project Homepage: http://fulgur.ch.vu\n\n"
				+ "This program is free software; you can redistribute it and/or modify\n"
				+ "it under the terms of the GNU General Public License as published by\n"
				+ "the Free Software Foundation; either version 2 of the License, or\n"
				+ "(at your option) any later version.\n\n"
				+ "This program is distributed in the hope that it will be useful,\n"
				+ "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
				+ "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
				+ "GNU General Public License for more details.\n\n"
				+ "You should have received a copy of the GNU General Public License\n"
				+ "along with this program; if not, write to the Free Software Foundation,\n"
				+ "Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA",
			"About JarBuilder",
			JOptionPane.INFORMATION_MESSAGE,
			varutils.loadIcon("JarBuilder.gif"));
	
	}
	
	// ---------- End implementation of the inherited abstract methods from JBMenuInterface ----------
	
	
	// ---------- Start implementation of the inherited abstract methods from JBButtonInterface ----------
	
	public void requestButtonAddFiles() {
		jbcore.loadFiles();
	}
	
	public void requestButtonRemoveFiles() {
		jbcore.removeEntry();
	}

	public void requestButtonClearList() {
		jbcore.clearFileList();
	}
	
	public void requestButtonCreateJar(){
		jbcore.prepareJar();
	}
	
	public void requestButtonClearAll() {
		jbcore.clearFileList();
		panel2.getTAManifest().setText("");
		panel2.setRadioButton(0, true);
		panel3.setCompressionRate(9);
	}
	
	public void requestButtonQuit() {
		dispose();
		System.exit(0);
	}
	
	public void requestButtonAbort() {
		jbcore.abortBuildProcess();
	}

	// ---------- End implementation of the inherited abstract methods from JBButtonInterface ----------



	/**
	 * Constructor for JarBuilder
	 */
	public JarBuilder() {
		// load the VarUtils Class
		varutils = new VarUtils();


		// load the kunststoff L&F
		try {	
			UIManager.setLookAndFeel("com.incors.plaf.kunststoff.KunststoffLookAndFeel");
		} 
		catch (Exception e) {
			JOptionPane.showMessageDialog(this, "Sorry, but I couldn't load the Kunststoff Look & Feel.\n"
			+ "Please put the \"kunstoff.jar\" file into the same directory as the \"JarBuilder.jar\" file.\n" 
			+ "With the Kunststoff Look & Feel JarBuilder just looks better...",
			"JarBuilder Error", JOptionPane.ERROR_MESSAGE);
		}
			
			
		setTitle("JarBuilder 0.8.0");
		setResizable(false);
		getContentPane().setLayout(new BorderLayout());
		setIconImage(varutils.loadIcon("JarBuilder.gif").getImage());

		
		
		// --------------------------- window content -----------------------------
		
		// general GridBagConstraints
		GridBagConstraints a = varutils.getDefaultGridBagCons();

		panelMain = new JPanel(new GridBagLayout());
		
		// menu bar

		JMenuBar myMenu = new JBMenu(this);
		setJMenuBar(myMenu);
		
		// create panels
		panel1 = new Panel1(this);
		panel2 = new Panel2(this);
		panel3 = new Panel3(this);
		panel4 = new Panel4(this);


		// add panels to panelMain
		a.gridx = 0; 
		a.gridy = 0;
		panelMain.add(panel1, a);

		a.gridy = 1;
		panelMain.add(panel2, a);

		a.gridy = 3;
		panelMain.add(panel3, a);


		// main panel to window
		getContentPane().add(panelMain, BorderLayout.CENTER);
		
		// --------------------------- window methods -----------------------------
		
		// WindowListener
		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				dispose();
				System.exit(0);
			}
		});


		// ------------------------- last configurations --------------------------
		// make an instance of the JBCore class
		jbcore = new JBCore(this, panelMain, panel1, panel2, panel3, panel4);

		pack();
		setVisible(true);	
		
		// fixate the size of the jscrollpane
		panel1.setListScrollPaneSize(new Dimension(panel1.getListScrollPaneSize()));
		
	}	
	
	
	public static void main(String[] args) {
		JarBuilder app = new JarBuilder();
	}	
	
	
}
